Module dicom_parser::dataset

source ·
Interpretation of DICOM data sets as streams of tokens.

Re-exports

pub use self::read::DataSetReader;
pub use self::write::DataSetWriter;

Modules

This module contains a mid-level abstraction for reading DICOM content sequentially and in a lazy fashion. That is, unlike the reader in the read module, DICOM values can be skipped and most allocations can be avoided.
This module contains a mid-level abstraction for reading DICOM content sequentially.
Module for the data set writer

Structs

A newtype for interpreting the given data as an item. When converting a value of this type into tokens, the inner value’s tokens will be surrounded by an item start and an item delimiter.
Flatten a sequence of elements into their respective token sequence in order.
A newtype for wrapping a piece of raw data into an item. When converting a value of this type into tokens, the algorithm will create an item start with an explicit length, followed by an item value token, then an item delimiter.
A newtype for wrapping a sequence of u32s into an offset table item. When converting a value of this type into tokens, the algorithm will create an item start with an explicit length, followed by an item value token, then an item delimiter.

Enums

Token generator from a DICOM data element.
A token of a DICOM data set stream. This is part of the interpretation of a data set as a stream of symbols, which may either represent data headers or actual value data.
A lazy data token for reading a data set without requiring values to be fully read in memory. This is part of the interpretation of a data set as a stream of symbols, which may either represent data headers or actual value data.
A structured description of a lazy data token, for diagnostics and error reporting purposes.
The type of delimiter: sequence or item.

Traits

A trait for converting structured DICOM data into a stream of data tokens.

Type Definitions