pub struct LazyDataSetReader<S> { /* private fields */ }
An attached iterator for retrieving DICOM object element markers from a random access data source.

This iterator produces data tokens without eagerly reading the bytes of a value.

Implementations

Create a new lazy data set reader with the given random access source and element dictionary, while considering the given transfer syntax and specific character set.

Create a new iterator with the given stateful decoder.

Advance and retrieve the next DICOM data token.

Note: For the data set to be successfully parsed, the resulting data tokens needs to be consumed if they are of a value type.