#[non_exhaustive]pub struct DataSetReaderOptions {
pub value_read: ValueReadStrategy,
pub charset_override: CharacterSetOverride,
pub odd_length: OddLengthStrategy,
pub base_offset: u64,
pub flexible_decoding: bool,
}Expand description
The set of options for the data set reader.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value_read: ValueReadStrategyThe value reading strategy
charset_override: CharacterSetOverrideWhether to assume a different character set depending on certain conditions
odd_length: OddLengthStrategyThe strategy for handling odd length data elements
base_offset: u64The position of the reader as received at building time in bytes. Defaults to 0.
flexible_decoding: boolWhen enabled, the decoder will probe the first non-meta element to determine whether the dataset actually uses explicit or implicit VR, regardless of what the transfer syntax declares.
This handles non-conformant files that declare Explicit VR Little Endian
but actually encode the dataset in Implicit VR.
Defaults to false.
Implementations
Sourceimpl DataSetReaderOptions
impl DataSetReaderOptions
Sourcepub fn value_read(self, value_read: ValueReadStrategy) -> Self
pub fn value_read(self, value_read: ValueReadStrategy) -> Self
Replace the value reading strategy of the options.
Sourcepub fn base_offset(self, base_offset: u64) -> Self
pub fn base_offset(self, base_offset: u64) -> Self
Replace the base reader offset of the options.
Sourcepub fn flexible_decoding(self, flexible_decoding: bool) -> Self
pub fn flexible_decoding(self, flexible_decoding: bool) -> Self
Enable or disable flexible VR decoding.