Struct dicom_parser::dataset::AsItem
source · pub struct AsItem<I>(_, _);Expand description
A newtype for interpreting the given data as an item. When converting a value of this type into tokens, the inner value’s tokens will be surrounded by an item start and an item delimiter.