[−][src]Struct dicom_parser::dataset::DicomElementMarker
A data type for a DICOM element residing in a file, or any other source with random access. A position in the file is kept for future access.
Fields
header: DataElementHeaderThe header, kept in memory. At this level, the value representation "UN" may also refer to a non-applicable vr (i.e. for items and delimiters).
pos: u64The ending position of the element's header (or the starting position of the element's value if it exists), relative to the beginning of the file.
Methods
impl DicomElementMarker[src]
pub fn get_data_stream<S: ?Sized, B: DerefMut<Target = S>>(
&self,
source: B
) -> Result<SeekInterval<S, B>> where
S: ReadSeek, [src]
&self,
source: B
) -> Result<SeekInterval<S, B>> where
S: ReadSeek,
Obtain an interval of the raw data associated to this element's data value.
pub fn move_to_start<S: ?Sized, B: DerefMut<Target = S>>(
&self,
source: B
) -> Result<()> where
S: Seek, [src]
&self,
source: B
) -> Result<()> where
S: Seek,
Move the source to the position indicated by the marker
pub fn vr(&self) -> VR[src]
Getter for this element's value representation. May be UN
when this is not applicable.