pub struct ItemValue<P>(_);
A newtype for wrapping a piece of raw data into an item. When converting a value of this type into tokens, the algorithm will create an item start with an explicit length, followed by an item value token, then an item delimiter.