Struct dicom_parser::dataset::OffsetTableItem
source · pub struct OffsetTableItem<P>(_);Expand description
A newtype for wrapping a sequence of u32s into an offset table item.
When converting a value of this type into tokens,
the algorithm will create an item start with an explicit length,
followed by an item value token,
then an item delimiter.