Module dicom_parser::dataset::write
source · Expand description
Module for the data set writer
This module contains a mid-level abstraction for printing DICOM data sets
sequentially.
The DataSetWriter receieves data tokens to be encoded and written
to a writer.
In this process, the writer will also adapt values
to the necessary DICOM encoding rules.
Structs
A stateful device for printing a DICOM data set in sequential order.
This is analogous to the
DatasetReader type for converting data
set tokens to bytes.