pub struct DataSetWriter<W, E, T = SpecificCharacterSet> { /* private fields */ }
A stateful device for printing a DICOM data set in sequential order. This is analogous to the DatasetReader type for converting data set tokens to bytes.

Implementations

Feed the given sequence of tokens which are part of the same data set.

Feed the given data set token for writing the data set.