[−][src]Module dicom_parser::error
Structs
| CastValueError | An error type for an attempt of accessing a value in an inappropriate format. |
Enums
| DataSetSyntaxError | |
| Error | The main data type for errors in the library. |
| InvalidValueReadError | Triggered when a value parsing attempt fails. |
Type Definitions
| Result | Type alias for a result from this crate. |