[−]Enum dicom_parser::error::Error
The main data type for errors in the library.
Variants
InvalidFormatNot valid DICOM content, typically raised when checking the magic code.
UnexpectedElementRaised when the obtained data element was not the one expected.
UnexpectedDataValueLengthRaised when the obtained length is inconsistent.
IllegalDataReadRaised when a read was illegally attempted.
UnsupportedTransferSyntaxRaised when the demanded transfer syntax is not supported.
UnsupportedCharacterSetRaised when the required character set is not supported.
NoSuchAttributeNameRaised when attempting to fetch an element by an unknown attribute name.
NoSuchDataElementRaised when attempting to fetch an unexistent element.
PixelDataOutOfBoundsRaised when attempting to read pixel data out of bounds.
MissingElementValueRaised when a data set parser couldn't fetch a value after a primitive data element's header.
DataSetSyntax(DataSetSyntaxError)Raised while parsing a DICOM data set and found an unexpected element header or value.
ReadValue(InvalidValueReadError)Error related to an invalid value read.
TextEncoding(TextEncodingError)Error related to a failed text encoding / decoding procedure.
CastValue(CastValueError)A failed attempt to cast a value to an inappropriate format.
Io(Error)Other I/O errors.