[−][src]Struct dicom_parser::parser::DicomParser
A data structure for parsing DICOM data.
This type encapsulates the necessary codecs in order
to be as autonomous as possible in the DICOM content reading
process.
S is the generic parameter type for the original source's type,
D is the parameter type that the decoder interprets as,
whereas DB is the parameter type for the basic decoder.
TextCodec defines the text codec used underneath.
Methods
impl<D, BD, S: ?Sized, TC> DicomParser<D, BD, S, TC> where
D: Decode<Source = S>,
BD: BasicDecode,
S: Read,
TC: TextCodec, [src]
D: Decode<Source = S>,
BD: BasicDecode,
S: Read,
TC: TextCodec,
pub fn new(decoder: D, basic: BD, text: TC) -> DicomParser<D, BD, S, TC>[src]
Create a new DICOM parser from its parts.