Enum dicom_parser::dataset::LazyDataTokenRepr
source · pub enum LazyDataTokenRepr {
ElementHeader(DataElementHeader),
SequenceStart {
tag: Tag,
len: Length,
},
PixelSequenceStart,
SequenceEnd,
ItemStart {
len: Length,
},
ItemEnd,
LazyValue {
header: DataElementHeader,
},
LazyItemValue {
len: u32,
},
}Expand description
A structured description of a lazy data token, for diagnostics and error reporting purposes.
Variants
ElementHeader(DataElementHeader)
A data header of a primitive value.
SequenceStart
The beginning of a sequence element.
PixelSequenceStart
The beginning of an encapsulated pixel data element.
SequenceEnd
The ending delimiter of a sequence or encapsulated pixel data.
ItemStart
The beginning of a new item in the sequence.
ItemEnd
The ending delimiter of an item.
LazyValue
Fields

header: DataElementHeaderthe header of the respective value
An element value yet to be fetched
LazyItemValue
An item value yet to be fetched