pub enum LazyDataTokenRepr {
    ElementHeader(DataElementHeader),
    SequenceStart {
        tag: Tag,
        len: Length,
    },
    PixelSequenceStart,
    SequenceEnd,
    ItemStart {
        len: Length,
    },
    ItemEnd,
    LazyValue {
        header: DataElementHeader,
    },
    LazyItemValue {
        len: u32,
    },
}
A structured description of a lazy data token, for diagnostics and error reporting purposes.

Variants



ElementHeader(DataElementHeader)

A data header of a primitive value.



SequenceStart

Fields

tag: Tag
len: Length

The beginning of a sequence element.



PixelSequenceStart

The beginning of an encapsulated pixel data element.



SequenceEnd

The ending delimiter of a sequence or encapsulated pixel data.



ItemStart

Fields

len: Length

The beginning of a new item in the sequence.



ItemEnd

The ending delimiter of an item.



LazyValue

Fields

header: DataElementHeader

the header of the respective value

An element value yet to be fetched



LazyItemValue

Fields

len: u32

the full length of the value, always well defined

An item value yet to be fetched