Struct dicom_parser::dataset::lazy_read::LazyDataSetReader
source · pub struct LazyDataSetReader<S> { /* private fields */ }Expand description
An attached iterator for retrieving DICOM object element markers from a random access data source.
This iterator produces data tokens without eagerly reading the bytes of a value.
Implementations
sourceimpl<R> LazyDataSetReader<DynStatefulDecoder<R>>
impl<R> LazyDataSetReader<DynStatefulDecoder<R>>
sourcepub fn new_with_ts_cs(
source: R,
ts: &TransferSyntax,
cs: SpecificCharacterSet
) -> Result<Self>where
R: ReadSeek,
pub fn new_with_ts_cs(
source: R,
ts: &TransferSyntax,
cs: SpecificCharacterSet
) -> Result<Self>where
R: ReadSeek,
Create a new lazy data set reader with the given random access source and element dictionary, while considering the given transfer syntax and specific character set.