Struct dicom_parser::dataset::read::DataSetReaderOptions
source · #[non_exhaustive]pub struct DataSetReaderOptions {
pub value_read: ValueReadStrategy,
pub base_offset: u64,
}Expand description
The set of options for the data set reader.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value_read: ValueReadStrategythe value reading strategy
base_offset: u64the position of the reader as received at building time
Implementations
sourceimpl DataSetReaderOptions
impl DataSetReaderOptions
sourcepub fn value_read(self, value_read: ValueReadStrategy) -> Self
pub fn value_read(self, value_read: ValueReadStrategy) -> Self
Replace the value reading strategy of the options.
sourcepub fn base_offset(self, base_offset: u64) -> Self
pub fn base_offset(self, base_offset: u64) -> Self
Replace the base reader offset of the options.